# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
# flake8: noqa

from stripe.api_resources.gift_cards.card import Card as Card
from stripe.api_resources.gift_cards.transaction import (
    Transaction as Transaction,
)
